<td>
    <center>
        <span class='fa fa-refresh fa-spin fa-fw text-info' ng-if='!row.error && row.sending' alt='{{data.meta.gentranslate.sending}}...' title='{{data.meta.gentranslate.sending}}...'></span>
        <span class='fa fa-envelope-o text-success' ng-if='!row.error && !row.sending && row.sent' alt='{{data.meta.gentranslate.sent}}' title='{{data.meta.gentranslate.sent}}'></span>
        <span class='fa fa-envelope-open-o' ng-if='!row.error && !row.sending && !row.sent' alt='{{data.meta.gentranslate.waiting}}' title='{{data.meta.gentranslate.waiting}}'></span>
        <span ng-if='row.error' alt='{{data.meta.gentranslate.notsent}}' title='{{data.meta.gentranslate.notsent}}' codenerix-html-compile="false|codenerix"></span>
    </center>
</td>
<td><center>{{row.priority|codenerix}}</center></td>
<td class="text-nowrap">{{row.created|codenerix}}</td>
<td class="text-nowrap">{{row.updated|codenerix}}</td>
<td>
    <span title="{{row.opened}}" codenerix-html-compile="row.opened|codenerix:'bool'"><span>
</td>
<td>{{row.eto|codenerix}}</td>
<td><nobr>{{row.subject|codenerix}}</nobr></td>
<td class="text-nowrap">{{row.bounces_total_count|codenerix}}</td>
<td><center>{{row.retries|codenerix}}</center></td>
<td class="text-nowrap">{{row.next_retry|codenerix}}</td>
<td><center>{{row.pk|codenerix}}</center></td>
<td ng-click="$event.stopPropagation();" align="center">
    <nobr><i title="{{row.uuid}}" codenerix-html-compile="row.uuid|codenerix:'copytoclipboard:UUID:UUID copiado al portapapales...'"></i></nobr>
</td>
<td ng-click="$event.stopPropagation();" align="center">
    <i codenerix-html-compile="row.unsubscribe_url|codenerix:'link:blank:onlyicon'"></i>
</td>
<td ng-click="$event.stopPropagation();">
    <center>
        <button class="btn" title="{{row.content_subtype|codenerix}}">
            <i ng-show="row.content_subtype=='plain'" class="fa fa-file-text-o" aria-hidden="true"></i>
            <i ng-show="row.content_subtype=='html'" class="fa fa-code" aria-hidden="true"></i>
            <i ng-hide="(row.content_subtype=='plain') || (row.content_subtype=='html')"class="fa fa-question-circle-o" aria-hidden="true"></i>
        </button>
    </center>
</td>
